<?php   

defined('C5_EXECUTE') or die(_("Access Denied."));

class TonyStatsPackage extends Package {

	protected $pkgHandle = 'tony_stats';
	protected $appVersionRequired = '5.3.3';
	protected $pkgVersion = '2.35'; 
	
	public function getPackageDescription() {
		return t("Monitor your sites traffic, users statistics, and paths"); 
	}
	
	public function getPackageName() {
		return t("Traffic & Statistics"); 
	}
	
	public function upgrade(){
		$result = parent::upgrade();
		$this->configure(); 
		return $result;
	}
	
	public function install() {
		$pkg = parent::install();
		$this->configure();
	}
	
	public function configure(){  
		
		$pkg = Package::getByHandle('tony_stats'); 
		
		// install block		
		//BlockType::installBlockTypeFromPackage('tony_stats', $pkg);	
		
		if( file_exists( $pkg->getPackagePath().'/controllers/dashboard/stats.php' ) ) 
			@unlink( $pkg->getPackagePath().'/controllers/dashboard/stats.php' );
			
		if( file_exists( $pkg->getPackagePath().'/single_pages/dashboard/stats.php' ) ) 
			@unlink( $pkg->getPackagePath().'/single_pages/dashboard/stats.php' );			
			
		if( file_exists( $pkg->getPackagePath().'/controllers/dashboard/stats.php' ) ||
			file_exists( $pkg->getPackagePath().'/single_pages/dashboard/stats.php' )  ) 
			throw new Exception( t('Please delete the following files: ').
								   $pkg->getPackagePath().'/single_pages/dashboard/stats.php'.' '.
								   $pkg->getPackagePath().'/controllers/dashboard/stats.php' );
		
		//install dashboard page
		Loader::model('single_page');
		$statsPage=Page::getByPath('/dashboard/stats'); 
		if( !intval($statsPage->cID) ){ 
			$statsPage=SinglePage::add('/dashboard/stats', $pkg);
		}
		$statsPage->update(array('cName'=>t('Traffic & Statistics'), 'cDescription'=>t('Monitor site visits and user paths'))); 
	
		//summary
		$statsOverviewPage=Page::getByPath('/dashboard/stats/summary');
		if( !intval($statsOverviewPage->cID) ){ 
			$statsOverviewPage=SinglePage::add('/dashboard/stats/summary', $pkg); 
		}
		$statsOverviewPage->update(array('cName'=>t('Statistics'), 'cDescription'=>t('Monitor site visits and user paths')));		
	
		//settings
		$statsSettingsPage=Page::getByPath('/dashboard/stats/settings');
		if( !intval($statsSettingsPage->cID) ){ 
			$statsSettingsPage=SinglePage::add('/dashboard/stats/settings', $pkg);
		}
		$statsSettingsPage->update(array('cName'=>t('Settings'), 'cDescription'=>t('Configure the statistics settings')));		
		
		//map
		$statsMapPage=Page::getByPath('/dashboard/stats/map');
		if( !intval($statsMapPage->cID) ){ 
			$statsMapPage=SinglePage::add('/dashboard/stats/map', $pkg);
		}
		$statsMapPage->update(array('cName'=>t('Map'), 'cDescription'=>t('View user locations')));		
		
		
		//add tracking script to footer
		$existingTrackingCode=Config::get('SITE_TRACKING_CODE');
		$existingTrackingCode=preg_replace('/<!--STATS JS START-->(.*?)<!--STATS JS END-->/ie','',$existingTrackingCode);
		$script='<script src="'.View::url('/tools/packages/'.$this->pkgHandle.'/services').'?mode=tracker_js" type="text/javascript"></script>';
		$existingTrackingCode.='<!--STATS JS START-->'.$script.'<!--STATS JS END-->';		
		Config::save('SITE_TRACKING_CODE', $existingTrackingCode); 
		
		
		$trackingSettings = unserialize(Config::get('TONY_STATS_TRACKING_SETTINGS'));
		if(!is_array($trackingSettings)) $trackingSettings=array();  
		if( !isset($trackingSettings['ignoredDomains']) && !is_array($trackingSettings['ignoredDomains']) ){
			$trackingSettings['ignoredDomains']= array( 'rate-limited-proxy-google.com' ); 
			Config::save('TONY_STATS_TRACKING_SETTINGS', serialize($trackingSettings) ); 
		}
		
		
		//install/replace dashboard homepage module
		Loader::model('dashboard/homepage');
		$statsModule=DashboardHomepageView::getByHandle('tony_stats'); 
		if( !$statsModule || !$statsModule->pkgID==$pkg->getPackageID() ){
			
			//set display numbers on homepage modules
			$dh = new DashboardHomepageView();
			$modules = $dh->getModules(); 
			$i=0; 
			foreach($modules as $module){
				$i++;
				if($i==2) $i++;
				$module->dbhDisplayOrder=$i; 
				$module->save();
			} 
			
			//add new module, and set it to the second position
			$statsModule=DashboardHomepageView::add( 'tony_stats', t('Traffic'), $pkg );
			$statsModule->dbhDisplayOrder=2;
			$statsModule->save();
			
			$oldStatsModule=DashboardHomepageView::getByHandle('reports');
			if( $oldStatsModule &&  $oldStatsModule->dbhModule){
				$oldStatsModule->dbhDisplayOrder=1000;
				$oldStatsModule->save();
			}
		}
		
		
		//install ip2nation data  
		$db = Loader::db();
		$sql = file_get_contents( $pkg->getPackagePath().'/libraries/ip2nation/ip2nation.sql' ); 
		foreach( explode(';',$sql) as $sqlLine){ 
			if( strlen(trim($sqlLine))<2 ) continue;  
			$db->query( $sqlLine );  
		}
	}
	
	public function uninstall(){
		Loader::model('dashboard/homepage');
		if( method_exists(DashboardHomepageView,'remove') ){
			DashboardHomepageView::remove('tony_stats');
		}else{
			$db=Loader::db();
			$db->query( 'DELETE FROM DashboardHomepage WHERE dbhModule="tony_stats"' );
		} 
		
		$oldStatsModule=DashboardHomepageView::getByHandle('reports');
		if( $oldStatsModule && $oldStatsModule->dbhModule){
			$oldStatsModule->dbhDisplayOrder=2;
			$oldStatsModule->save();
		} 
		
		return parent::uninstall(); 
	}

}