<?php 

defined('C5_EXECUTE') or die(_("Access Denied."));  

class DashboardStatsSummaryController extends Controller { 

	function __construct(){ 
	
		$packageHandle='tony_stats';
		$statsPkg = Package::getByHandle($packageHandle);  
		require_once( $statsPkg->getPackagePath().'/helpers/stats.php' ); 
		
		Loader::model('panel',$packageHandle);
	}
	
	function view(){   
		$panels = ParticleTrafficPanel::getPanels();
		if(!count($panels)) ParticleTrafficPanel::registerDefaultPanels();
		
		$this->set( 'c', $this->getCollectionObject() );
	} 
	
	
	function save_panel_position(){ 
		
		$column = $_POST['col'];
		if( !in_array($column,array('A','B','C')) ) throw new Exception( t('Invalid column letter') );  
		
		$db= Loader::db();
		
		$position=0;
		if( is_array($_POST['panels'])) foreach($_POST['panels'] as $panel_id){ 
			$position++;
			$vals=array( $position, $column, intval($panel_id) );
			$sql="UPDATE TonyStatsPanels SET position= ?, col= ? WHERE panel_id=?";
			$queryResult = $db->query($sql,$vals);
		} 
		
		die; 
	}
	
	
	//method names in your panel controller must begin with "action_"
	function panel_service($panel_handle='',$method_name=''){
		
		$panel = ParticleTrafficPanel::getByHandle($panel_handle);
		if(!$panel) throw new Exception('Panel not found');
		
		if(!strstr($method_name,'action_')) $method_name='action_'.$method_name;
		if(!method_exists($panel,$method_name)) throw new Exception('Method not found');
		$panel->$method_name();
		
		die; 
	}
	
	
	function export(){
		
		$statsDisplay=new ParticleTrafficDisplay(); 
		
		if( !class_exists('excel_xml') ) 
			Loader::library('excel_xml','tony_stats'); 
			
		$excel = new excel_xml();  
		
		$excel->add_style('header', array( 'bold'=>1, 'size' =>'14') );  
		$excel->add_style('subheader', array( 'bold'=>1 ) ); 
		
		
		
		

		//Days 
		//********************************************* 
		
		$excel->add_row( $this->encodeXMLdata(array(
			t('Date'),	 
			t('Visits'),
			t('Page Views'))
		), 'header');

		
		$visitsData = $statsDisplay->getVisitData(1); 
		
		$successiveBlankDays=0;
		
		for($i=0;$i<=(7*4);$i++){ 
			
			$visits = intval( $visitsData['days'][date('Y_n_z',time()-($i*3600*24))]['visits'] );
			
			$data=array();
			$data[]= date( 'l, F j, Y', time()-($i*3600*24) ); 
			$data[]= $visits; 
			$data[]= intval( $visitsData['days'][date('Y_n_z',time()-($i*3600*24))]['pageviews'] ); 
			
			$excel->add_row( $this->encodeXMLdata($data) );
			
			if( !$visits ) $successiveBlankDays++;
			else $successiveBlankDays=0;
			
			if($successiveBlankDays>=4) break;  
			
		}
		$excel->create_worksheet( t('Daily Popularity') );  


		//Hours 
		//********************************************* 
		
		$excel->add_row( $this->encodeXMLdata(array(
			t('Date'),	
			t('Hour'),			  
			t('Visits'),
			t('Page Views'))
		), 'header'); 
		
		for($i=0;$i<=72;$i++){ 
			
			$data=array();
			$data[]= date('F j, Y',time()-($i*3600));
			$data[]= date('g:00 a',time()-($i*3600));
			$data[]= intval( $visitsData['hours'][date('Y_n_z_G',time()-($i*3600))]['visits'] ); 
			$data[]= intval( $visitsData['hours'][date('Y_n_z_G',time()-($i*3600))]['pageviews'] ); 
			
			$excel->add_row( $this->encodeXMLdata($data) );
			
		}
		$excel->create_worksheet( t('Hourly Popularity') ); 
		
		
		
		//Months 
		//********************************************* 
		
		$excel->add_row( $this->encodeXMLdata(array(
			t('Month'),	 			  
			t('Visits'),
			t('Page Views'))
		), 'header'); 
		
		for($i=0;$i<=36;$i++){ 
			
			$time=mktime(1,1,1,date('n')-$i,1,date('Y'));
			
			$visits = intval( $visitsData['months'][date('Y_n',$time)]['visits'] );
			$views = intval( $visitsData['months'][date('Y_n',$time)]['pageviews'] ); 
			
			$data=array();
			$data[]= date('M y',$time); 
			$data[]= $visits; 
			$data[]= $views;
			
			if( !$visits && !$views) break; 
			
			$excel->add_row( $this->encodeXMLdata($data) );
			
		}
		$excel->create_worksheet( t('Monthly Popularity') ); 		
		
		
		
		
		//User Visits (without hits)
		//********************************************* 
		
		$excel->add_row( $this->encodeXMLdata(array(
			t('Visit Date'),			  
			t('IP'),
			t('Host'),
			t('Pages Viewed'), 
			t('User'),
			t('Browser'),
			t('Flash Version'),
			t('Referrer') ,
			t('Country')) 
		), 'header');

		
		$visits = $statsDisplay->getVisitPaths(false,0);
		
		foreach( $visits as $visit ){
			
			$pagesViewed=count($visit['hitData']); 
			
			$visitingUser = '';
			if( intval($visit['users_id']) ){ 
				$user = ParticleTrafficDisplay::getCachedUser($visit['users_id']);
				$visitingUser = $user->getUserName();
			} 
			
			$browser = '';
			if( strlen($visit['browser']) && strtolower($visit['browser'])!='unrecognized'){ 
				$browser = ParticleTrafficDisplay::cleanBrowserName($visit['browser']) .' '. intval($visit['browser_version']);
			} 
			
			$country=('');
			$countryData = ParticleTrafficDisplay::getCountryDataFromIP( $visit['ip'] );
			if( count($countryData) && strlen($countryData['iso_code_2']) ){ 
				$country = t($countryData['country']);
			}	
			 
			$flashVersion = ( strlen($visit['flash_version']) ) ? floatval($visit['flash_version']) : '';  
			
			$data=array();
			$data[]= date('F j, Y, g:i a',$visit['created']); 
			$data[]= $visit['ip'];
			$data[]= $visit['host_name']; 
			$data[]= $pagesViewed;
			$data[]= $visitingUser;
			$data[]= $browser; 
			$data[]= $flashVersion; 
			$data[]= $visit['referrer_url']; 
			$data[]= $country; 
			
			$excel->add_row( $this->encodeXMLdata($data) );
			
		}
		$excel->create_worksheet( t('User Visits') ); 
		
		
		
		
		//User Visits (with hits) 
		//*********************************************
		
		$excel->add_row( $this->encodeXMLdata(array(
			t('Date'),
			t('User IP / URL'),
			t('Host / Title'), 
			t('Page Count / Durations')) 
		), 'header'); 
		
		$excel->column_width=250;
		
		foreach( $visits as $visit ){
			
			$pagesViewed=count($visit['hitData']); 
			
			$visitingUser = '';
			if( intval($visit['users_id']) ){ 
				$user = ParticleTrafficDisplay::getCachedUser($visit['users_id']);
				$visitingUser = $user->getUserName();
			}    
			
			$data=array();
			$data[]= date('F j, Y, g:i:s a',$visit['created']); 
			$data[]= $visit['ip']; 
			$data[]= $visit['host_name']; 
			$data[]= $pagesViewed; 
			
			$excel->add_row( $this->encodeXMLdata($data), 'subheader');
			
			$lastHitTime=0;
			if( is_array($visit['hitData'])) foreach($visit['hitData'] as $hit ){
				
				if($lastHitTime==0){
					$duration= ($hit['created']>(date('U')-ParticleTrafficTracker::$visitTimeout)) ? t('Viewing') : t('Timed Out');
				}else{
					$duration= ParticleTrafficTools::timeLengthLabel($lastHitTime-$hit['created']);
				}
				
				$hitData=array();
				$hitData[]= date( 'F j, Y, g:i:s a', $hit['created'] ); 
				//$hitData[]= '<a href="'.ParticleTrafficTools::formatPageURL($hit['page_url']) .'">'.
				//		 ParticleTrafficTools::formatPageName( $hit['page_title'], $hit['page_url']).'</a>'; 
				$hitData[]= $hit['page_url'];//ParticleTrafficTools::formatPageName( $hit['page_title'], $hit['page_url']); 
				$hitData[]= $hit['page_title'];
				$hitData[]= $duration;  
				$excel->add_row( $this->encodeXMLdata($hitData) );
				$lastHitTime=$hit['created']; 
			}
		} 
		$excel->create_worksheet( t('Visit Pages') ); 		
		
		
		
		
		//Hits 
		//********************************************* 
		
		$excel->add_row( $this->encodeXMLdata(array(
			t('Time'),	 
			t('Page URL'),
			t('Page Title'))
		), 'header');
		
		$hits = $statsDisplay->getRecentHits();
		
		foreach($hits as $hit){  
			
			$data=array(); 
			$data[]= date( 'F j, Y, g:i:s a', $hit['created'] ); 
			$data[]= $hit['page_url']; 
			$data[]= $hit['page_title']; 
			
			$excel->add_row( $this->encodeXMLdata($data) ); 
		}
		$excel->create_worksheet( t('Page Views') ); 
		
		
		
		
		//Registered User Visits (with hits) 
		//*********************************************
		
		$excel->add_row( $this->encodeXMLdata(array(
			t('Date'),
			t('User Name / URL'),
			t('IP / Title'), 
			t('Page Count / Durations')) 
		), 'header'); 
		
		$excel->column_width=250;
		
		foreach( $visits as $visit ){
			
			$pagesViewed=count($visit['hitData']); 
			
			$visitingUser = '';
			if( intval($visit['users_id']) ){ 
				$user = ParticleTrafficDisplay::getCachedUser($visit['users_id']);
				$visitingUser = $user->getUserName();
			}     
			
			if(!$visitingUser) continue; 
			
			$data=array();
			$data[]= date('F j, Y, g:i:s a',$visit['created']); 
			$data[]= $visitingUser; 
			$data[]= $visit['ip']; 
			$data[]= $pagesViewed; 
			
			$excel->add_row( $this->encodeXMLdata($data), 'subheader');
			
			$lastHitTime=0;
			if( is_array($visit['hitData'])) foreach($visit['hitData'] as $hit ){
				
				if($lastHitTime==0){
					$duration= ($hit['created']>(date('U')-ParticleTrafficTracker::$visitTimeout)) ? t('Viewing') : t('Timed Out');
				}else{
					$duration= ParticleTrafficTools::timeLengthLabel($lastHitTime-$hit['created']);
				}
				
				$hitData=array();
				$hitData[]= date( 'F j, Y, g:i:s a', $hit['created'] ); 
				//$hitData[]= '<a href="'.ParticleTrafficTools::formatPageURL($hit['page_url']) .'">'.
				//		 ParticleTrafficTools::formatPageName( $hit['page_title'], $hit['page_url']).'</a>'; 
				$hitData[]= $hit['page_url'];//ParticleTrafficTools::formatPageName( $hit['page_title'], $hit['page_url']); 
				$hitData[]= $hit['page_title'];
				$hitData[]= $duration;  
				$excel->add_row( $this->encodeXMLdata($hitData) );
				$lastHitTime=$hit['created']; 
			}
		} 
		$excel->create_worksheet( t('Registered Users') ); 		
		
		
		
		
		//Print Results
		//**********************************************
		
		header("Content-Type: application/vnd.ms-excel; charset=UTF-8");
		//header( "content-type: text/xml" ); 
		header("Cache-control: private");
		header("Pragma: public");
		$date = date('Y-m-d');
		header("Content-Disposition: attachment; filename=stats_excel_export_{$date}.xml"); 
		header("Content-Title:  ". t('Statistics Export') ."- {$date}");	
		
		header("Content-Transfer-Encoding: binary");
		
		echo $excel->generate();
		
		
		die;
	} 
	
	protected function encodeXMLdata( $vals=array() ){
		$newArray=array();
		foreach($vals as $val) $newArray[]=htmlspecialchars($val); 
		return $vals; //$newArray;
	}
	
}

?>